summaryrefslogtreecommitdiffstats
path: root/unix/tclUnixInit.c
diff options
context:
space:
mode:
authordas <das>2003-05-13 08:41:26 (GMT)
committerdas <das>2003-05-13 08:41:26 (GMT)
commitb5af58fb48b98becd450e3d7b1e9753d3154d7b9 (patch)
treee3f550a92be8b1397d2e40c10ee51a7bef9dcb89 /unix/tclUnixInit.c
parenta41f586cbbb2bccd146270743f2479e007b12cb9 (diff)
downloadtcl-b5af58fb48b98becd450e3d7b1e9753d3154d7b9.zip
tcl-b5af58fb48b98becd450e3d7b1e9753d3154d7b9.tar.gz
tcl-b5af58fb48b98becd450e3d7b1e9753d3154d7b9.tar.bz2
* generic/tcl.decls:
* macosx/tclMacOSXBundle.c: added extended version of the Tcl_MacOSXOpenBundleResources() API taking an extra version number argument: Tcl_MacOSXOpenVersionedBundleResources(). This is needed to be able to access bundle resources in versioned frameworks such as Tcl and Tk, otherwise if multiple versions were installed, only the latest version's resources could be accessed. [Bug 736774] * unix/tclUnixInit.c (Tcl_MacOSXGetLibraryPath): use new versioned bundle resource API to get tcl runtime library for TCL_VERSION. [Bug 736774] * generic/tclPlatDecls.h: * generic/tclStubInit.c: regen. * unix/tclUnixPort.h: worked around the issue of realpath() not being thread-safe on Mac OS X by defining NO_REALPATH for threaded builds on Mac OS X. [Bug 711232]
Diffstat (limited to 'unix/tclUnixInit.c')
-rw-r--r--unix/tclUnixInit.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/unix/tclUnixInit.c b/unix/tclUnixInit.c
index 5be58f5..ae3d2a3 100644
--- a/unix/tclUnixInit.c
+++ b/unix/tclUnixInit.c
@@ -7,7 +7,7 @@
* Copyright (c) 1999 by Scriptics Corporation.
* All rights reserved.
*
- * RCS: @(#) $Id: tclUnixInit.c,v 1.34 2002/10/22 16:41:28 das Exp $
+ * RCS: @(#) $Id: tclUnixInit.c,v 1.34.2.1 2003/05/13 08:41:26 das Exp $
*/
#if defined(HAVE_CFBUNDLE)
@@ -1027,7 +1027,7 @@ TclpCheckStackSpace()
* TCL_OK if we have found the tcl library; TCL_ERROR otherwise.
*
* Side effects:
* Same as for Tcl_MacOSXOpenBundleResources.
*
*----------------------------------------------------------------------
*/
@@ -1035,8 +1035,8 @@ static int Tcl_MacOSXGetLibraryPath(Tcl_Interp *interp, int maxPathLen, char *tc
{
int foundInFramework = TCL_ERROR;
if (strcmp(defaultLibraryDir, "@TCL_IN_FRAMEWORK@") == 0) {
- foundInFramework = Tcl_MacOSXOpenBundleResources(interp,
- "com.tcltk.tcllibrary", 0, maxPathLen, tclLibPath);
+ foundInFramework = Tcl_MacOSXOpenVersionedBundleResources(interp,
+ "com.tcltk.tcllibrary", TCL_VERSION, 0, maxPathLen, tclLibPath);
}
return foundInFramework;
}
@@ -1027,7 +1027,7 @@ TclpCheckStackSpace()
*
* Side effects:
- * Same as for Tcl_MacOSXOpenBundleResources.
+ * Same as for Tcl_MacOSXOpenVersionedBundleResources.
*
*----------------------------------------------------------------------